@@ -1,5 +1,6 @@
 import asyncio
 import datetime
+from pathlib import Path
 from typing import Callable
 
 import aiofiles.os
@@ -19,9 +20,9 @@ class Daemon:
         self,
         watch_path: str,
         db: Session,
-        create_dag_func: Callable[[str, Session, asyncio.Queue], Dag],
+        create_dag_func: Callable[[str, Session], Dag],
     ):
-        self.watch_path = watch_path
+        self.watch_path = Path(watch_path)
         self.db = db
         self.create_dag_func = create_dag_func
         self.dags_pending_queue = asyncio.Queue(maxsize=32)
@@ -75,7 +76,7 @@ class Daemon:
                 continue
             while not self.dags_pending_queue.empty():
                 dag = await self.dags_pending_queue.get()
-                self.aiotask_to_dag[asyncio.create_task(dag.run())] = dag
+                self.aiotask_to_dag[asyncio.create_task(dag.run(self.pending_queue))] = dag
 
     async def handlers_dags(self):
         while True:
@@ -108,7 +109,9 @@ class Daemon:
             await asyncio.sleep(constant.SLEEP_TIME)
 
     def create_dag(self, file: str) -> Dag:
-        return self.create_dag_func(file, self.db, self.pending_queue)
+        dag = self.create_dag_func(file, self.db)
+        print('dag for file', file, 'created')
+        return dag
 
     async def update_files_dags(self) -> None:
         """create dags for new files"""
@@ -124,14 +127,14 @@ class Daemon:
 
     async def watch_directory(self):
         while True:
-            files = set(await aiofiles.os.listdir(self.watch_path))
+            files = {str(self.watch_path / p) for p in await aiofiles.os.listdir(self.watch_path)}
             stale_files_ids = set()
             up_to_date_files_paths = set()
             for file in file_crud.read_many(self.db):
-                if file.path not in files:
-                    stale_files_ids.add(file.id)
-                else:
+                if file.path in files:
                     up_to_date_files_paths.add(file.path)
+                else:
+                    stale_files_ids.add(file.id)
             file_crud.delete_many_by_ids(self.db, stale_files_ids)
             file_crud.create_many(self.db, [schemas.FileCreate(path=file) for file in files - up_to_date_files_paths])
             await asyncio.sleep(constant.SLEEP_TIME)
