@@ -1,14 +1,11 @@
 import os
 import sys
 
-import dotenv
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 
 from dagops.state import models
 
-dotenv.load_dotenv()
-
 engine = create_engine(os.environ['DB_URL'], connect_args={'check_same_thread': False}, echo=False)
 SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)
 
